@@ -26,20 +26,25 @@ def create_route(endpoint: Dict, handler: Callable, method: str, app: FastAPI):
             content = result
         for header, value in result.get("headers", {}).items():
             response.headers[header] = value
-        return JSONResponse(
-            content=content, status_code=status_code, headers=response.headers
-        )
+        if status_code == 204:
+            response = Response(status_code=status_code)
+        else:
+            response = JSONResponse(
+                content=content, status_code=status_code, headers=response.headers
+            )
+        return response
 
 
 def get_query_params(multi_params: Optional[Dict]) -> Dict:
     params = {}
     if multi_params:
         for param in multi_params:
-            params[param] = multi_params[param][0]
+            params[param] = multi_params[param][-1]
         return params
 
 
 def get_multi_value_params(url: str) -> Dict:
+    """extract parmas from url for multiqueryParams"""
     url = str(url).split("/")[-1]
     params = url.split("?")[-1]
     params = params.split("&")
